@@ -28,9 +28,9 @@
 #pod =for :this This is C<Dist::Zilla::Plugin::Templates> module documentation. Read this if you are going to hack or
 #pod extend C<Dist-Zilla-Plugin-Templates>.
 #pod
-#pod =for :that If you want to convert any text file into template, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
+#pod =for :those If you want to convert any text file into template, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
 #pod topics like getting source, building, installing, bug reporting and some others are covered in the
-#pod L<readme|Dist::Zilla::Plugin::Templates::ReadMe>.
+#pod F<README>.
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -45,7 +45,6 @@
 #pod = L<Dist::Zilla::Role::TextTemplater>
 #pod = L<Text::Template>
 #pod = L<Dist::Zilla::Plugin::Templates::Manual>
-#pod = L<Dist::Zilla::Plugin::Templates::ReadMe>
 #pod
 #pod =cut
 
@@ -57,7 +56,7 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Convert any text file into template
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 with 'Dist::Zilla::Role::FileMunger';
 with 'Dist::Zilla::Role::FileFinderUser' => {
@@ -67,6 +66,8 @@ with 'Dist::Zilla::Role::FileFinderUser' => {
 with 'Dist::Zilla::Role::TextTemplater' => { -version => 0.004 };   # need `fill_in_file`.
 with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 
+use Dist::Zilla::Plugin::Templates::File;
+
 # --------------------------------------------------------------------------------------------------
 
 #pod =attr template
@@ -75,7 +76,6 @@ with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 #pod
 #pod TODO
 #pod
-#pod
 #pod # --------------------------------------------------------------------------------------------------
 #pod
 #pod =method munge_files
@@ -89,7 +89,18 @@ with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 sub munge_files {
     my ( $self ) = @_;
     for my $file ( @{ $self->found_files } ) {
-        $self->fill_in_file( $file );
+        $self->fill_in_file(
+            $file,
+            {
+                include => \ &{ sub {       # `Text::Template` wants double reference.
+                    my ( $name ) = shift( @_ );
+                    return Dist::Zilla::Plugin::Templates::File->new( {
+                        name    => $name,
+                        _plugin => $self,
+                    } );
+                } },
+            },
+        );
     };
     return;
 };
@@ -132,7 +143,7 @@ Dist::Zilla::Plugin::Templates - Convert any text file into template
 
 =head1 VERSION
 
-Version 0.002, released on 2015-08-11 23:13 UTC.
+Version 0.003, released on 2015-08-30 18:40 UTC.
 
 =head1 WHAT?
 
@@ -146,7 +157,7 @@ extend C<Dist-Zilla-Plugin-Templates>.
 
 If you want to convert any text file into template, read the L<manual|Dist::Zilla::Plugin::Templates::Manual>. General
 topics like getting source, building, installing, bug reporting and some others are covered in the
-L<readme|Dist::Zilla::Plugin::Templates::ReadMe>.
+F<README>.
 
 =head1 DESCRIPTION
 
@@ -185,8 +196,6 @@ $self->fill_in_file >> (a method taken from C<TextTemplater> role). That's all,
 
 =item L<Dist::Zilla::Plugin::Templates::Manual>
 
-=item L<Dist::Zilla::Plugin::Templates::ReadMe>
-
 =back
 
 =head1 AUTHOR
